@@ -17,10 +17,10 @@ class DbAccess : public QObject
     Q_OBJECT
     Q_PROPERTY(QString errorMessage READ errorMessage NOTIFY errorMessageChanged)
 public:
-    explicit DbAccess(QObject* parent = 0);
+    explicit DbAccess(QObject* parent = nullptr);
     QString errorMessage() const;
 
-signals:
+Q_SIGNALS:
     void errorMessageChanged();
 
 protected:
