@@ -15,11 +15,6 @@ class TrainingConfigWidget : public QWidget, private Ui::TrainingConfigWidget
     Q_OBJECT
 public:
     explicit TrainingConfigWidget(QWidget *parent = nullptr);
-
-signals:
-
-public slots:
-
 };
 
 #endif // TRAININGCONFIGWIDGET_H
